@@ -113,7 +113,7 @@
 #' setting of \code{stationary} for \code{ctFit}, this matrix is ignored as the effects are determined based on
 #' the overall process parameters.
 #' 
-#' @param TIPREDVAR symmetric n.TIpred * n.TIpred variance / covariance
+#' @param TIPREDVAR lower triangular n.TIpred * n.TIpred Cholesky decomposed covariance
 #' matrix for all time independent predictors.
 #' "auto" (default) freely estimates all parameters.
 #' 
@@ -121,7 +121,9 @@
 #' and the value sets the starting value for that parameter during optimization.
 #' If not set, random starting values representing relatively stable processes with small effects and 
 #' covariances are generated by ctFit.  
-#' Better starting values may improve model fit speed and the chance of an appropriate model fit.  
+#' Better starting values may improve model fit speed and the chance of an appropriate model fit. 
+#' 
+#' @param timeVarying character vector of matrices to allow to vary over measurement occasions. Currently only accepts 'MANIFESTMEANS'. 
 #' @examples 
 #' 
 #'  ### impulse and level change time dependent predictor example from Driver, Oud, Voelkle (2015)
@@ -163,7 +165,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
   TRAITTDPREDCOV="auto", TDTIPREDCOV='auto',
   n.TIpred=0, TIpredNames='auto', TIPREDMEANS="auto", TIPREDEFFECT="auto", 
   T0TIPREDEFFECT="auto", TIPREDVAR="auto", 
-  startValues=NULL){
+  startValues=NULL, timeVarying=NULL){
   
   
   
@@ -469,7 +471,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
     TDPREDEFFECT, TDPREDMEANS, T0TDPREDCOV, TRAITTDPREDCOV,
     TIPREDEFFECT, TIPREDMEANS, T0TIPREDEFFECT,
     TIPREDVAR, TDPREDVAR,TDTIPREDCOV,   
-    startValues)
+    startValues, timeVarying)
   
   names(completemodel)<-c("n.manifest","n.latent","n.TDpred","n.TIpred","Tpoints","LAMBDA",
     "manifestNames","latentNames","TDpredNames","TIpredNames",
@@ -478,7 +480,7 @@ ctModel<-function(n.manifest, n.latent, Tpoints, LAMBDA,
     'TDPREDEFFECT', 'TDPREDMEANS', 'T0TDPREDCOV', 'TRAITTDPREDCOV',
     'TIPREDEFFECT', 'TIPREDMEANS', 'T0TIPREDEFFECT',
     'TIPREDVAR', 'TDPREDVAR','TDTIPREDCOV',  
-    "startValues")
+    "startValues", 'timeVarying')
   
   
   
